Class: SwaggerAemClient::SamlConfigurationProperties

Inherits:
Object
  • Object
show all
Defined in:
lib/swagger_aem/models/saml_configuration_properties.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SamlConfigurationProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 153

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'path')
    if (value = attributes[:'path']).is_a?(Array)
      self.path = value
    end
  end

  if attributes.has_key?(:'service.ranking')
    if (value = attributes[:'service.ranking']).is_a?(Array)
      self.service_ranking = value
    end
  end

  if attributes.has_key?(:'idpUrl')
    if (value = attributes[:'idpUrl']).is_a?(Array)
      self.idp_url = value
    end
  end

  if attributes.has_key?(:'idpCertAlias')
    if (value = attributes[:'idpCertAlias']).is_a?(Array)
      self.idp_cert_alias = value
    end
  end

  if attributes.has_key?(:'idpHttpRedirect')
    if (value = attributes[:'idpHttpRedirect']).is_a?(Array)
      self.idp_http_redirect = value
    end
  end

  if attributes.has_key?(:'serviceProviderEntityId')
    if (value = attributes[:'serviceProviderEntityId']).is_a?(Array)
      self.service_provider_entity_id = value
    end
  end

  if attributes.has_key?(:'assertionConsumerServiceURL')
    if (value = attributes[:'assertionConsumerServiceURL']).is_a?(Array)
      self.assertion_consumer_service_url = value
    end
  end

  if attributes.has_key?(:'spPrivateKeyAlias')
    if (value = attributes[:'spPrivateKeyAlias']).is_a?(Array)
      self.sp_private_key_alias = value
    end
  end

  if attributes.has_key?(:'keyStorePassword')
    if (value = attributes[:'keyStorePassword']).is_a?(Array)
      self.key_store_password = value
    end
  end

  if attributes.has_key?(:'defaultRedirectUrl')
    if (value = attributes[:'defaultRedirectUrl']).is_a?(Array)
      self.default_redirect_url = value
    end
  end

  if attributes.has_key?(:'userIDAttribute')
    if (value = attributes[:'userIDAttribute']).is_a?(Array)
      self.user_id_attribute = value
    end
  end

  if attributes.has_key?(:'useEncryption')
    if (value = attributes[:'useEncryption']).is_a?(Array)
      self.use_encryption = value
    end
  end

  if attributes.has_key?(:'createUser')
    if (value = attributes[:'createUser']).is_a?(Array)
      self.create_user = value
    end
  end

  if attributes.has_key?(:'addGroupMemberships')
    if (value = attributes[:'addGroupMemberships']).is_a?(Array)
      self.add_group_memberships = value
    end
  end

  if attributes.has_key?(:'groupMembershipAttribute')
    if (value = attributes[:'groupMembershipAttribute']).is_a?(Array)
      self.group_membership_attribute = value
    end
  end

  if attributes.has_key?(:'defaultGroups')
    if (value = attributes[:'defaultGroups']).is_a?(Array)
      self.default_groups = value
    end
  end

  if attributes.has_key?(:'nameIdFormat')
    if (value = attributes[:'nameIdFormat']).is_a?(Array)
      self.name_id_format = value
    end
  end

  if attributes.has_key?(:'synchronizeAttributes')
    if (value = attributes[:'synchronizeAttributes']).is_a?(Array)
      self.synchronize_attributes = value
    end
  end

  if attributes.has_key?(:'handleLogout')
    if (value = attributes[:'handleLogout']).is_a?(Array)
      self.handle_logout = value
    end
  end

  if attributes.has_key?(:'logoutUrl')
    if (value = attributes[:'logoutUrl']).is_a?(Array)
      self.logout_url = value
    end
  end

  if attributes.has_key?(:'clockTolerance')
    if (value = attributes[:'clockTolerance']).is_a?(Array)
      self.clock_tolerance = value
    end
  end

  if attributes.has_key?(:'digestMethod')
    if (value = attributes[:'digestMethod']).is_a?(Array)
      self.digest_method = value
    end
  end

  if attributes.has_key?(:'signatureMethod')
    if (value = attributes[:'signatureMethod']).is_a?(Array)
      self.signature_method = value
    end
  end

  if attributes.has_key?(:'userIntermediatePath')
    if (value = attributes[:'userIntermediatePath']).is_a?(Array)
      self.user_intermediate_path = value
    end
  end

end

Instance Attribute Details

#add_group_membershipsObject

Whether or not a user should be automatically added to CRX groups after successful authentication.



58
59
60
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 58

def add_group_memberships
  @add_group_memberships
end

#assertion_consumer_service_urlObject

The (optional) AssertionConsumerServiceURL attribute of an Authn request specifies the location to which a <Response> message MUST be sent to the requester.



37
38
39
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 37

def assertion_consumer_service_url
  @assertion_consumer_service_url
end

#clock_toleranceObject

Time tolerance in seconds to compensate clock skew between IDP and SP when validating Assertions.



79
80
81
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 79

def clock_tolerance
  @clock_tolerance
end

#create_userObject

Whether or not to autocreate nonexisting users in the repository.



55
56
57
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 55

def create_user
  @create_user
end

#default_groupsObject

A list of default CRX groups users are added to after successful authentication.



64
65
66
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 64

def default_groups
  @default_groups
end

#default_redirect_urlObject

The default location to redirect to after successful authentication.



46
47
48
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 46

def default_redirect_url
  @default_redirect_url
end

#digest_methodObject

The digest algorithm to use when signing a SAML message.



82
83
84
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 82

def digest_method
  @digest_method
end

#group_membership_attributeObject

The name of the attribute containing a list of CRX groups this user should be added to.



61
62
63
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 61

def group_membership_attribute
  @group_membership_attribute
end

#handle_logoutObject

Whether or not logout (dropCredentials) requests will be processed by this handler.



73
74
75
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 73

def handle_logout
  @handle_logout
end

#idp_cert_aliasObject

The alias of the IdP’s certificate in the global truststore. If this property is empty the authentication handler is disabled.



28
29
30
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 28

def idp_cert_alias
  @idp_cert_alias
end

#idp_http_redirectObject

Use an HTTP Redirect to the IDP URL instead of sending an AuthnRequest-message to request credentials. Use this for IDP initiated authentication.



31
32
33
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 31

def idp_http_redirect
  @idp_http_redirect
end

#idp_urlObject

URL of the IDP where the SAML Authentication Request should be sent to. If this property is empty the authentication handler is disabled. (idpUrl)



25
26
27
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 25

def idp_url
  @idp_url
end

#key_store_passwordObject

The password of the key-store of the ‘authentication-service’ system user.



43
44
45
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 43

def key_store_password
  @key_store_password
end

#logout_urlObject

URL of the IDP where the SAML Logout Request should be sent to. If this property is empty the authentication handler won’t handle logouts.



76
77
78
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 76

def logout_url
  @logout_url
end

#name_id_formatObject

The value of the NameIDPolicy format parameter to send in the AuthnRequest message.



67
68
69
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 67

def name_id_format
  @name_id_format
end

#pathObject

Repository path for which this authentication handler should be used by Sling. If this is empty, the authentication handler will be disabled.



19
20
21
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 19

def path
  @path
end

#service_provider_entity_idObject

ID which uniquely identifies this service provider with the identity provider. If this property is empty the authentication handler is disabled.



34
35
36
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 34

def service_provider_entity_id
  @service_provider_entity_id
end

#service_rankingObject

OSGi Framework Service Ranking value to indicate the order in which to call this service. This is an int value where higher values designate higher precedence. Default value is 0.



22
23
24
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 22

def service_ranking
  @service_ranking
end

#signature_methodObject

The signature algorithm to use when signing a SAML message.



85
86
87
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 85

def signature_method
  @signature_method
end

#sp_private_key_aliasObject

The alias of the SP’s private key in the key-store of the ‘authentication-service’ system user. If this property is empty the handler will not be able to sign or decrypt messages.



40
41
42
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 40

def sp_private_key_alias
  @sp_private_key_alias
end

#synchronize_attributesObject

A list of attribute mappings (in the format \attributename=path/relative/to/user/node\) which should be stored in the repository on user-synchronization.



70
71
72
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 70

def synchronize_attributes
  @synchronize_attributes
end

#use_encryptionObject

Whether or not this authentication handler expects encrypted SAML assertions. If this is enabled the SP’s private key must be provided in the key-store of the ‘authentication-service’ system user (see SP Private Key Alias above).



52
53
54
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 52

def use_encryption
  @use_encryption
end

#user_id_attributeObject

The name of the attribute containing the user ID used to authenticate and create the user in the CRX repository. Leave empty to use the Subject:NameId.



49
50
51
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 49

def user_id_attribute
  @user_id_attribute
end

#user_intermediate_pathObject

User intermediate path to store created users.



88
89
90
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 88

def user_intermediate_path
  @user_intermediate_path
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 92

def self.attribute_map
  {
    :'path' => :'path',
    :'service_ranking' => :'service.ranking',
    :'idp_url' => :'idpUrl',
    :'idp_cert_alias' => :'idpCertAlias',
    :'idp_http_redirect' => :'idpHttpRedirect',
    :'service_provider_entity_id' => :'serviceProviderEntityId',
    :'assertion_consumer_service_url' => :'assertionConsumerServiceURL',
    :'sp_private_key_alias' => :'spPrivateKeyAlias',
    :'key_store_password' => :'keyStorePassword',
    :'default_redirect_url' => :'defaultRedirectUrl',
    :'user_id_attribute' => :'userIDAttribute',
    :'use_encryption' => :'useEncryption',
    :'create_user' => :'createUser',
    :'add_group_memberships' => :'addGroupMemberships',
    :'group_membership_attribute' => :'groupMembershipAttribute',
    :'default_groups' => :'defaultGroups',
    :'name_id_format' => :'nameIdFormat',
    :'synchronize_attributes' => :'synchronizeAttributes',
    :'handle_logout' => :'handleLogout',
    :'logout_url' => :'logoutUrl',
    :'clock_tolerance' => :'clockTolerance',
    :'digest_method' => :'digestMethod',
    :'signature_method' => :'signatureMethod',
    :'user_intermediate_path' => :'userIntermediatePath'
  }
end

.swagger_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 122

def self.swagger_types
  {
    :'path' => :'Array<SamlConfigurationPropertyItemsArray>',
    :'service_ranking' => :'Array<SamlConfigurationPropertyItemsLong>',
    :'idp_url' => :'Array<SamlConfigurationPropertyItemsString>',
    :'idp_cert_alias' => :'Array<SamlConfigurationPropertyItemsString>',
    :'idp_http_redirect' => :'Array<SamlConfigurationPropertyItemsBoolean>',
    :'service_provider_entity_id' => :'Array<SamlConfigurationPropertyItemsString>',
    :'assertion_consumer_service_url' => :'Array<SamlConfigurationPropertyItemsString>',
    :'sp_private_key_alias' => :'Array<SamlConfigurationPropertyItemsString>',
    :'key_store_password' => :'Array<SamlConfigurationPropertyItemsString>',
    :'default_redirect_url' => :'Array<SamlConfigurationPropertyItemsString>',
    :'user_id_attribute' => :'Array<SamlConfigurationPropertyItemsString>',
    :'use_encryption' => :'Array<SamlConfigurationPropertyItemsBoolean>',
    :'create_user' => :'Array<SamlConfigurationPropertyItemsBoolean>',
    :'add_group_memberships' => :'Array<SamlConfigurationPropertyItemsBoolean>',
    :'group_membership_attribute' => :'Array<SamlConfigurationPropertyItemsString>',
    :'default_groups' => :'Array<SamlConfigurationPropertyItemsArray>',
    :'name_id_format' => :'Array<SamlConfigurationPropertyItemsString>',
    :'synchronize_attributes' => :'Array<SamlConfigurationPropertyItemsArray>',
    :'handle_logout' => :'Array<SamlConfigurationPropertyItemsBoolean>',
    :'logout_url' => :'Array<SamlConfigurationPropertyItemsString>',
    :'clock_tolerance' => :'Array<SamlConfigurationPropertyItemsLong>',
    :'digest_method' => :'Array<SamlConfigurationPropertyItemsString>',
    :'signature_method' => :'Array<SamlConfigurationPropertyItemsString>',
    :'user_intermediate_path' => :'Array<SamlConfigurationPropertyItemsString>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 320

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      path == o.path &&
      service_ranking == o.service_ranking &&
      idp_url == o.idp_url &&
      idp_cert_alias == o.idp_cert_alias &&
      idp_http_redirect == o.idp_http_redirect &&
      service_provider_entity_id == o.service_provider_entity_id &&
      assertion_consumer_service_url == o.assertion_consumer_service_url &&
      sp_private_key_alias == o.sp_private_key_alias &&
      key_store_password == o.key_store_password &&
      default_redirect_url == o.default_redirect_url &&
      user_id_attribute == o.user_id_attribute &&
      use_encryption == o.use_encryption &&
      create_user == o.create_user &&
      add_group_memberships == o.add_group_memberships &&
      group_membership_attribute == o.group_membership_attribute &&
      default_groups == o.default_groups &&
      name_id_format == o.name_id_format &&
      synchronize_attributes == o.synchronize_attributes &&
      handle_logout == o.handle_logout &&
      logout_url == o.logout_url &&
      clock_tolerance == o.clock_tolerance &&
      digest_method == o.digest_method &&
      signature_method == o.signature_method &&
      user_intermediate_path == o.user_intermediate_path
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 385

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SwaggerAemClient.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



451
452
453
454
455
456
457
458
459
460
461
462
463
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 451

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 364

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 351

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



357
358
359
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 357

def hash
  [path, service_ranking, idp_url, idp_cert_alias, idp_http_redirect, service_provider_entity_id, assertion_consumer_service_url, sp_private_key_alias, key_store_password, default_redirect_url, user_id_attribute, use_encryption, create_user, add_group_memberships, group_membership_attribute, default_groups, name_id_format, synchronize_attributes, handle_logout, logout_url, clock_tolerance, digest_method, signature_method, user_intermediate_path].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



307
308
309
310
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 307

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



431
432
433
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 431

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



437
438
439
440
441
442
443
444
445
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 437

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



425
426
427
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 425

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



314
315
316
# File 'lib/swagger_aem/models/saml_configuration_properties.rb', line 314

def valid?
  return true
end